@@ -206,16 +206,20 @@ class LxTokenizer(ToolWrapper):
         tokenizer_input = f"<s> {raw_sentence} </s>"
         self.writeline(tokenizer_input)
         tokenizer_output = self.readline().strip()
+        # under some conditions, the tokenizer delays outputing </s> until a new
+        # sentence is fed; in such situations, we skip the </s> and get the next line:
+        if tokenizer_output == "</s>":  
+            tokenizer_output = self.readline().strip()
         ok = True
         if not tokenizer_output.startswith("<s>"):
             ok = False
-            LOG.warning("tokenizer removed <s> from begining of line")
+            LOG.debug("tokenizer removed <s> from begining of line")
         if not tokenizer_output.endswith("</s>"):
             ok = False
-            LOG.warning("tokenizer removed </s> from end of line")
+            LOG.debug("tokenizer removed </s> from end of line")
         if not ok:
-            LOG.warning(f"tokenizer input: {tokenizer_input!r}")
-            LOG.warning(f"tokenizer output: {tokenizer_output!r}")
+            LOG.debug(f"tokenizer input: {tokenizer_input!r}")
+            LOG.debug(f"tokenizer output: {tokenizer_output!r}")
         tokenizer_output = tokenizer_output.replace("<s>", "").replace("</s>", "")
         forms = tokenizer_output.strip().split()
         forms = [
